@@ -53,19 +53,19 @@ class RetryTest(utils.EngineTestBase):
         flow = lf.Flow('flow-1', utils.OneReturnRetry(provides='x'))
         engine = self._make_engine(flow)
         engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'x': 1})
+        self.assertEqual({'x': 1}, engine.storage.fetch_all())
 
     def test_run_empty_unordered_flow(self):
         flow = uf.Flow('flow-1', utils.OneReturnRetry(provides='x'))
         engine = self._make_engine(flow)
         engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'x': 1})
+        self.assertEqual({'x': 1}, engine.storage.fetch_all())
 
     def test_run_empty_graph_flow(self):
         flow = gf.Flow('flow-1', utils.OneReturnRetry(provides='x'))
         engine = self._make_engine(flow)
         engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'x': 1})
+        self.assertEqual({'x': 1}, engine.storage.fetch_all())
 
     def test_states_retry_success_linear_flow(self):
         flow = lf.Flow('flow-1', retry.Times(4, 'r1', provides='x')).add(
@@ -76,14 +76,14 @@ class RetryTest(utils.EngineTestBase):
         engine.storage.inject({'y': 2})
         with utils.CaptureListener(engine) as capturer:
             engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2, 'x': 2})
+        self.assertEqual({'y': 2, 'x': 2}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'r1.r RUNNING', 'r1.r SUCCESS(1)',
                     'task1.t RUNNING', 'task1.t SUCCESS(5)',
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
-                    'task2.t REVERTING', 'task2.t REVERTED',
-                    'task1.t REVERTING', 'task1.t REVERTED',
+                    'task2.t REVERTING', 'task2.t REVERTED(None)',
+                    'task1.t REVERTING', 'task1.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task1.t PENDING',
                     'task2.t PENDING',
@@ -105,7 +105,7 @@ class RetryTest(utils.EngineTestBase):
         engine.storage.inject({'y': 4})
         with utils.CaptureListener(engine) as capturer:
             self.assertRaisesRegexp(RuntimeError, '^Woot', engine.run)
-        self.assertEqual(engine.storage.fetch_all(), {'y': 4})
+        self.assertEqual({'y': 4}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'r1.r RUNNING',
                     'r1.r SUCCESS(1)',
@@ -114,9 +114,9 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task1.t PENDING',
                     'task2.t PENDING',
@@ -127,11 +127,11 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -144,7 +144,7 @@ class RetryTest(utils.EngineTestBase):
         engine.storage.inject({'y': 4})
         with utils.CaptureListener(engine) as capturer:
             self.assertRaisesRegexp(RuntimeError, '^Gotcha', engine.run)
-        self.assertEqual(engine.storage.fetch_all(), {'y': 4, 'x': 1})
+        self.assertEqual({'y': 4, 'x': 1}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'r1.r RUNNING',
                     'r1.r SUCCESS(1)',
@@ -153,9 +153,9 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'task1.t REVERTING',
-                    'task1.t FAILURE',
+                    'task1.t REVERT_FAILURE(Failure: RuntimeError: Gotcha!)',
                     'flow-1.f FAILURE']
         self.assertEqual(expected, capturer.values)
 
@@ -172,7 +172,7 @@ class RetryTest(utils.EngineTestBase):
         engine.storage.inject({'y': 2})
         with utils.CaptureListener(engine) as capturer:
             engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2, 'x': 2})
+        self.assertEqual({'y': 2, 'x': 2}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'r1.r RUNNING',
                     'r1.r SUCCESS(None)',
@@ -185,9 +185,9 @@ class RetryTest(utils.EngineTestBase):
                     'task3.t RUNNING',
                     'task3.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task3.t REVERTING',
-                    'task3.t REVERTED',
+                    'task3.t REVERTED(None)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r2.r RETRYING',
                     'task2.t PENDING',
                     'task3.t PENDING',
@@ -215,8 +215,9 @@ class RetryTest(utils.EngineTestBase):
         engine.storage.inject({'y': 2})
         with utils.CaptureListener(engine) as capturer:
             engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2, 'x1': 2,
-                                                      'x2': 1})
+        self.assertEqual({'y': 2, 'x1': 2,
+                          'x2': 1},
+                         engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'r1.r RUNNING',
                     'r1.r SUCCESS(1)',
@@ -231,15 +232,15 @@ class RetryTest(utils.EngineTestBase):
                     'task4.t RUNNING',
                     'task4.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task4.t REVERTING',
-                    'task4.t REVERTED',
+                    'task4.t REVERTED(None)',
                     'task3.t REVERTING',
-                    'task3.t REVERTED',
+                    'task3.t REVERTED(None)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r2.r REVERTING',
-                    'r2.r REVERTED',
+                    'r2.r REVERTED(None)',
                     'task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task1.t PENDING',
                     'r2.r PENDING',
@@ -270,7 +271,7 @@ class RetryTest(utils.EngineTestBase):
         engine.storage.inject({'y': 2})
         with utils.CaptureListener(engine) as capturer:
             engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2, 'x': 2})
+        self.assertEqual({'y': 2, 'x': 2}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'r.r RUNNING',
                     'r.r SUCCESS(1)',
@@ -280,8 +281,8 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
                     'task1.t REVERTING',
-                    'task2.t REVERTED',
-                    'task1.t REVERTED',
+                    'task2.t REVERTED(None)',
+                    'task1.t REVERTED(None)',
                     'r.r RETRYING',
                     'task1.t PENDING',
                     'task2.t PENDING',
@@ -305,7 +306,7 @@ class RetryTest(utils.EngineTestBase):
         engine.storage.inject({'y': 2})
         with utils.CaptureListener(engine) as capturer:
             engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2, 'x': 2, 'x2': 1})
+        self.assertEqual({'y': 2, 'x': 2, 'x2': 1}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'r1.r RUNNING',
                     'r1.r SUCCESS(1)',
@@ -316,11 +317,11 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r2.r REVERTING',
-                    'r2.r REVERTED',
+                    'r2.r REVERTED(None)',
                     'task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task1.t PENDING',
                     'r2.r PENDING',
@@ -350,7 +351,7 @@ class RetryTest(utils.EngineTestBase):
                 engine.run()
             except Exception:
                 pass
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2})
+        self.assertEqual({'y': 2}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'task1.t RUNNING',
                     'task1.t SUCCESS(5)',
@@ -359,9 +360,9 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -379,7 +380,7 @@ class RetryTest(utils.EngineTestBase):
                 engine.run()
             except Exception:
                 pass
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2})
+        self.assertEqual({'y': 2}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'task1.t RUNNING',
                     'task1.t SUCCESS(5)',
@@ -388,11 +389,11 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -406,7 +407,7 @@ class RetryTest(utils.EngineTestBase):
         engine.storage.inject({'y': 2})
         with utils.CaptureListener(engine) as capturer:
             self.assertRaisesRegexp(RuntimeError, '^Woot', engine.run)
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2})
+        self.assertEqual({'y': 2}, engine.storage.fetch_all())
         expected = ['flow-1.f RUNNING',
                     'r1.r RUNNING',
                     'r1.r SUCCESS(1)',
@@ -417,13 +418,13 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r2.r REVERTING',
-                    'r2.r REVERTED',
+                    'r2.r REVERTED(None)',
                     'task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -471,7 +472,7 @@ class RetryTest(utils.EngineTestBase):
                     't3.t RUNNING',
                     't3.t SUCCESS(5)',
                     'flow-1.f SUCCESS']
-        self.assertEqual(capturer.values, expected)
+        self.assertEqual(expected, capturer.values)
 
     def test_resume_flow_that_should_be_retried(self):
         flow = lf.Flow('flow-1', retry.Times(3, 'r1')).add(
@@ -515,7 +516,7 @@ class RetryTest(utils.EngineTestBase):
                     'c.t RUNNING',
                     'c.t FAILURE(Failure: RuntimeError: Woot!)',
                     'c.t REVERTING',
-                    'c.t REVERTED',
+                    'c.t REVERTED(None)',
                     'r1.r RETRYING',
                     'c.t PENDING',
                     'r1.r RUNNING',
@@ -525,7 +526,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t SUCCESS(5)',
                     'flow-1.f SUCCESS']
-        self.assertEqual(capturer.values, expected)
+        self.assertEqual(expected, capturer.values)
 
     def test_default_times_retry(self):
         flow = lf.Flow('flow-1', retry.Times(3, 'r1')).add(
@@ -542,9 +543,9 @@ class RetryTest(utils.EngineTestBase):
                     't2.t RUNNING',
                     't2.t FAILURE(Failure: RuntimeError: Woot!)',
                     't2.t REVERTING',
-                    't2.t REVERTED',
+                    't2.t REVERTED(None)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     't2.t PENDING',
@@ -555,9 +556,9 @@ class RetryTest(utils.EngineTestBase):
                     't2.t RUNNING',
                     't2.t FAILURE(Failure: RuntimeError: Woot!)',
                     't2.t REVERTING',
-                    't2.t REVERTED',
+                    't2.t REVERTED(None)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     't2.t PENDING',
@@ -568,11 +569,11 @@ class RetryTest(utils.EngineTestBase):
                     't2.t RUNNING',
                     't2.t FAILURE(Failure: RuntimeError: Woot!)',
                     't2.t REVERTING',
-                    't2.t REVERTED',
+                    't2.t REVERTED(None)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -589,7 +590,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -597,7 +598,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 2)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -605,7 +606,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -613,9 +614,9 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 5)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -632,7 +633,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 2)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -640,7 +641,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -648,9 +649,9 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 5)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertItemsEqual(capturer.values, expected)
 
@@ -674,7 +675,7 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task2.t PENDING',
                     'r1.r RUNNING',
@@ -682,7 +683,7 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot with 2)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task2.t PENDING',
                     'r1.r RUNNING',
@@ -690,7 +691,7 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task2.t PENDING',
                     'r1.r RUNNING',
@@ -698,9 +699,9 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot with 5)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -724,7 +725,7 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task2.t PENDING',
                     'r1.r RUNNING',
@@ -732,7 +733,7 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot with 2)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task2.t PENDING',
                     'r1.r RUNNING',
@@ -740,7 +741,7 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task2.t PENDING',
                     'r1.r RUNNING',
@@ -748,11 +749,11 @@ class RetryTest(utils.EngineTestBase):
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot with 5)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -778,7 +779,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -786,7 +787,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 2)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -794,9 +795,9 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 5)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -814,7 +815,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -822,7 +823,7 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 2)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r RETRYING',
                     't1.t PENDING',
                     'r1.r RUNNING',
@@ -830,9 +831,9 @@ class RetryTest(utils.EngineTestBase):
                     't1.t RUNNING',
                     't1.t FAILURE(Failure: RuntimeError: Woot with 5)',
                     't1.t REVERTING',
-                    't1.t REVERTED',
+                    't1.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertItemsEqual(capturer.values, expected)
 
@@ -857,7 +858,7 @@ class RetryTest(utils.EngineTestBase):
                     'task-2.t RUNNING',
                     'task-2.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     'task-2.t REVERTING',
-                    'task-2.t REVERTED',
+                    'task-2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task-2.t PENDING',
                     'r1.r RUNNING',
@@ -865,7 +866,7 @@ class RetryTest(utils.EngineTestBase):
                     'task-2.t RUNNING',
                     'task-2.t FAILURE(Failure: RuntimeError: Woot with 2)',
                     'task-2.t REVERTING',
-                    'task-2.t REVERTED',
+                    'task-2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task-2.t PENDING',
                     'r1.r RUNNING',
@@ -873,9 +874,9 @@ class RetryTest(utils.EngineTestBase):
                     'task-2.t RUNNING',
                     'task-2.t FAILURE(Failure: RuntimeError: Woot with 5)',
                     'task-2.t REVERTING',
-                    'task-2.t REVERTED',
+                    'task-2.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -901,7 +902,7 @@ class RetryTest(utils.EngineTestBase):
                     'task-2.t RUNNING',
                     'task-2.t FAILURE(Failure: RuntimeError: Woot with 3)',
                     'task-2.t REVERTING',
-                    'task-2.t REVERTED',
+                    'task-2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task-2.t PENDING',
                     'r1.r RUNNING',
@@ -909,7 +910,7 @@ class RetryTest(utils.EngineTestBase):
                     'task-2.t RUNNING',
                     'task-2.t FAILURE(Failure: RuntimeError: Woot with 2)',
                     'task-2.t REVERTING',
-                    'task-2.t REVERTED',
+                    'task-2.t REVERTED(None)',
                     'r1.r RETRYING',
                     'task-2.t PENDING',
                     'r1.r RUNNING',
@@ -917,11 +918,11 @@ class RetryTest(utils.EngineTestBase):
                     'task-2.t RUNNING',
                     'task-2.t FAILURE(Failure: RuntimeError: Woot with 5)',
                     'task-2.t REVERTING',
-                    'task-2.t REVERTED',
+                    'task-2.t REVERTED(None)',
                     'r1.r REVERTING',
-                    'r1.r REVERTED',
+                    'r1.r REVERTED(None)',
                     'task-1.t REVERTING',
-                    'task-1.t REVERTED',
+                    'task-1.t REVERTED(None)',
                     'flow-1.f REVERTED']
         self.assertEqual(expected, capturer.values)
 
@@ -973,7 +974,7 @@ class RetryTest(utils.EngineTestBase):
         with utils.CaptureListener(engine) as capturer:
             engine.run()
         expected = ['task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'flow-1_retry.r RETRYING',
                     'task1.t PENDING',
                     'flow-1_retry.r RUNNING',
@@ -988,7 +989,7 @@ class RetryTest(utils.EngineTestBase):
         with utils.CaptureListener(engine) as capturer:
             engine.run()
         expected = ['task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'flow-1_retry.r RETRYING',
                     'task1.t PENDING',
                     'flow-1_retry.r RUNNING',
@@ -1003,7 +1004,7 @@ class RetryTest(utils.EngineTestBase):
         with utils.CaptureListener(engine) as capturer:
             engine.run()
         expected = ['task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'flow-1_retry.r RETRYING',
                     'task1.t PENDING',
                     'flow-1_retry.r RUNNING',
@@ -1018,7 +1019,7 @@ class RetryTest(utils.EngineTestBase):
         with utils.CaptureListener(engine) as capturer:
             engine.run()
         expected = ['task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'flow-1_retry.r RETRYING',
                     'task1.t PENDING',
                     'flow-1_retry.r RUNNING',
@@ -1032,7 +1033,7 @@ class RetryTest(utils.EngineTestBase):
         engine = self._pretend_to_run_a_flow_and_crash('revert scheduled')
         with utils.CaptureListener(engine) as capturer:
             engine.run()
-        expected = ['task1.t REVERTED',
+        expected = ['task1.t REVERTED(None)',
                     'flow-1_retry.r RETRYING',
                     'task1.t PENDING',
                     'flow-1_retry.r RUNNING',
@@ -1040,7 +1041,7 @@ class RetryTest(utils.EngineTestBase):
                     'task1.t RUNNING',
                     'task1.t SUCCESS(5)',
                     'flow-1.f SUCCESS']
-        self.assertEqual(capturer.values, expected)
+        self.assertEqual(expected, capturer.values)
 
     def test_retry_fails(self):
         r = FailingRetry()
@@ -1048,7 +1049,7 @@ class RetryTest(utils.EngineTestBase):
         engine = self._make_engine(flow)
         self.assertRaisesRegexp(ValueError, '^OMG', engine.run)
         self.assertEqual(1, len(engine.storage.get_retry_histories()))
-        self.assertEqual(len(r.history), 0)
+        self.assertEqual(0, len(r.history))
         self.assertEqual([], list(r.history.outcomes_iter()))
         self.assertIsNotNone(r.history.failure)
         self.assertTrue(r.history.caused_by(ValueError, include_retry=True))
@@ -1077,18 +1078,18 @@ class RetryTest(utils.EngineTestBase):
                     'c.t FAILURE(Failure: RuntimeError: Woot!)',
                     'a.t REVERTING',
                     'c.t REVERTING',
-                    'a.t REVERTED',
-                    'c.t REVERTED',
+                    'a.t REVERTED(None)',
+                    'c.t REVERTED(None)',
                     'b.t REVERTING',
-                    'b.t REVERTED']
+                    'b.t REVERTED(None)']
         self.assertItemsEqual(capturer.values[:8], expected)
         # Task 'a' was or was not executed again, both cases are ok.
         self.assertIsSuperAndSubsequence(capturer.values[8:], [
             'b.t RUNNING',
             'c.t FAILURE(Failure: RuntimeError: Woot!)',
-            'b.t REVERTED',
+            'b.t REVERTED(None)',
         ])
-        self.assertEqual(engine.storage.get_flow_state(), st.REVERTED)
+        self.assertEqual(st.REVERTED, engine.storage.get_flow_state())
 
     def test_nested_provides_graph_retried_correctly(self):
         flow = gf.Flow("test").add(
@@ -1107,9 +1108,9 @@ class RetryTest(utils.EngineTestBase):
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
         expected = ['c.t REVERTING',
-                    'c.t REVERTED',
+                    'c.t REVERTED(None)',
                     'b.t REVERTING',
-                    'b.t REVERTED']
+                    'b.t REVERTED(None)']
         self.assertItemsEqual(capturer.values[:4], expected)
         expected = ['test2_retry.r RETRYING',
                     'b.t PENDING',
@@ -1123,7 +1124,7 @@ class RetryTest(utils.EngineTestBase):
                     'a.t SUCCESS(5)',
                     'c.t SUCCESS(5)']
         self.assertItemsEqual(expected, capturer.values[4:])
-        self.assertEqual(engine.storage.get_flow_state(), st.SUCCESS)
+        self.assertEqual(st.SUCCESS, engine.storage.get_flow_state())
 
 
 class RetryParallelExecutionTest(utils.EngineTestBase):
@@ -1142,17 +1143,17 @@ class RetryParallelExecutionTest(utils.EngineTestBase):
         engine.storage.inject({'y': 2})
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2, 'x': 2})
+        self.assertEqual({'y': 2, 'x': 2}, engine.storage.fetch_all())
         expected = ['r.r RUNNING',
                     'r.r SUCCESS(1)',
                     'task1.t RUNNING',
                     'task2.t RUNNING',
                     'task2.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'task1.t SUCCESS(5)',
                     'task1.t REVERTING',
-                    'task1.t REVERTED',
+                    'task1.t REVERTED(None)',
                     'r.r RETRYING',
                     'task1.t PENDING',
                     'task2.t PENDING',
@@ -1178,7 +1179,7 @@ class RetryParallelExecutionTest(utils.EngineTestBase):
         engine.storage.inject({'y': 2})
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
-        self.assertEqual(engine.storage.fetch_all(), {'y': 2, 'x': 2})
+        self.assertEqual({'y': 2, 'x': 2}, engine.storage.fetch_all())
         expected = ['r.r RUNNING',
                     'r.r SUCCESS(1)',
                     'task1.t RUNNING',
@@ -1189,10 +1190,10 @@ class RetryParallelExecutionTest(utils.EngineTestBase):
                     'task3.t FAILURE(Failure: RuntimeError: Woot!)',
                     'task3.t REVERTING',
                     'task1.t REVERTING',
-                    'task3.t REVERTED',
-                    'task1.t REVERTED',
+                    'task3.t REVERTED(None)',
+                    'task1.t REVERTED(None)',
                     'task2.t REVERTING',
-                    'task2.t REVERTED',
+                    'task2.t REVERTED(None)',
                     'r.r RETRYING',
                     'task1.t PENDING',
                     'task2.t PENDING',
